from setuptools import setup

setup(name='hm_probability',
      version='1.0',
      description='Gaussian distributions',
      author='Hardik Makwana during Udacity Course ',
      packages=['hm_probability'],
      zip_safe=False)
